/************************************************************/
/*                                                          */
/* WINDOWS WIDGETS                                          */
/*                                                          */
/* R. Marsh, 1/10/13                                        */
/*                                                          */
/************************************************************/
#include <GL/gl.h>
#include <GL/glu.h>
#include <GL/freeglut.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>

#ifndef _windows_
#define _windows_

/***********************************************************/
/* CLASS PROTOTYPE                                         */
/***********************************************************/
class WINDOW {
   public:
     GLint xs, ys, xe, ye;
     char  text[80];
     WINDOW(GLint x, GLint y, GLint w, GLint h) {
        xs = x;
        ys = y;
        xe = (xs + w);
        ye = (ys + h);
        strcpy(text, "");
     };
     WINDOW(GLint x, GLint y, GLint w, GLint h, const char *label) {
        xs = x;
        ys = y;
        xe = (xs + w);
        ye = (ys + h);
        strcpy(text, label);
     };
     ~WINDOW() {};
     void DRAW();
     void CLEAR();
     void PAINT(GLfloat R, GLfloat G, GLfloat B);
     void BLUE() {
        PAINT(0.0, 0.0, 1.0);
     };
     void GREEN() {
        PAINT(0.0, 1.0, 0.0);
     };
     void YELLOW() {
        PAINT(1.0, 1.0, 0.0);
     };
     void RED() {
        PAINT(1.0, 0.0, 0.0);
     };
     void WHITE() {
        PAINT(1.0, 1.0, 1.0);
     };
     void DrawTEXT(GLfloat R, GLfloat G, GLfloat B, char text[]);
     void DrawTEXT(GLfloat R, GLfloat G, GLfloat B, int value);
     void DrawTEXT(GLfloat R, GLfloat G, GLfloat B, double value);
};

#endif

/***********************************************************/
/*                                                         */
/* BUTTON WIDGETS                                          */
/*                                                         */
/* R. Marsh, 1/10/13                                       */
/*                                                         */
/***********************************************************/
#include <GL/gl.h>
#include <GL/glu.h>
#include <GL/freeglut.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>

#ifndef _buttons_
#define _buttons_

/***********************************************************/
/* CLASS PROTOTYPE                                         */
/***********************************************************/
class BUTTON {
   public:
     int   state;
     GLint xs, ys;
     BUTTON(GLint x, GLint y, const char *text) {
        height  = 20;
        width   = 70;
        xs = x;
        ys = y;
        state = 0;
        strcpy(label, text);
     };
     BUTTON(GLint x, GLint y, GLint W, GLint H, const char *text, int S) {
        height  = H;
        width   = W;
        xs = x;
        ys = y;
        state = S;
        strcpy(label, text);
     };
     ~BUTTON() {};
     void DRAW();
     void DRAW_HILITE(GLfloat, GLfloat, GLfloat);
     void DRAW_LARGE(void);
     int  HIDE();
     int  SHOW();
     int  SELECTED(int, int);
     void CLICK(void);
     void CLICK_LARGE(int);

   private:
     GLint width, height;
     GLint xsb, xeb, ysb, yeb;
     char label[25];
     struct button {
        unsigned char r, g, b, a;
     } *Button;
};

#endif

/************************************************************/
/*                                                          */
/* SLIDER WIDGETS                                           */
/*                                                          */
/* R. Marsh, 1/10/13                                        */
/*                                                          */
/************************************************************/
#include <GL/gl.h>
#include <GL/glu.h>
#include <GL/freeglut.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>

#ifndef _sliders_
#define _sliders_

/***********************************************************/
/* CLASS PROTOTYPE                                         */
/***********************************************************/
class SLIDER {
   public:
     int max, step, value;
     GLint xs, ys;
     
     SLIDER(GLint x, GLint y, GLint W, const char text[], int M, int S, int V) {
        h  = 16;
        w  = W - 30;
        xs = x;
        ys = y;
        max   = M;
        step  = S;
        value = V;
        strcpy(label, text);
     };
     ~SLIDER() {};

     void DRAW(void);
     void WINDOW_DRAW(int, int);
     void WINDOW_CLEAR(int, int);
     void BUTTON_DRAW(int, int, const char *);
     int  RIGHT_SELECTED(int, int);
     int  LEFT_SELECTED(int, int);
     void LEFT_CLICK(int);
     void RIGHT_CLICK(int);

   private:
     GLint w, h;
     char label[25];
};

#endif

/************************************************************/
/*                                                          */
/* TEXT WIDGETS                                             */
/*                                                          */
/* R. Marsh, 1/10/13                                        */
/*                                                          */
/************************************************************/
#include <GL/gl.h>
#include <GL/glu.h>
#include <GL/freeglut.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#ifndef _text_
#define _text_

/***********************************************************/
/* FUNCTION PROTOTYPES                                     */
/***********************************************************/
void TEXT_HELVETICA_10(GLint, GLint, const char *);
void TEXT_HELVETICA_12(GLint, GLint, const char *);
void TEXT_HELVETICA_18(GLint, GLint, const char *);
void TEXT_8_X_13(GLint, GLint, const char *);
void TEXT_8_X_13_BLACK(GLint, GLint, const char *);
void TEXT_8_X_13_WHITE(GLint, GLint, const char *);
void TEXT_8_X_13_RED(GLint, GLint, const char *);
void TEXT_8_X_13_GREEN(GLint, GLint, const char *);
void TEXT_8_X_13_BLUE(GLint, GLint, const char *);
void CLEAR_8_X_13(GLint, GLint, GLint, GLint);

#endif

